=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2011-06-13 22:10:55 +0000
+++ bzrlib/config.py	2011-06-13 22:39:49 +0000
@@ -81,6 +81,7 @@
     bzrdir,
     debug,
     errors,
+    lazy_regex,
     lockdir,
     mail_client,
     mergetools,
@@ -2780,11 +2781,11 @@
             raise errors.NoSuchConfigOption(name)
 
     def _show_matching_options(self, name, directory, scope):
-        name = re.compile(name)
+        name = lazy_regex.lazy_compile(name)
         # We want any error in the regexp to be raised *now* so we need to
-        # avoid the delay introduced by the lazy regexp.
-        if getattr(name, _compile_and_collapse):
-            name._compile_and_collapse()
+        # avoid the delay introduced by the lazy regexp.  But, we still do
+        # want the nicer errors raised by lazy_regex.
+        name._compile_and_collapse()
         cur_conf_id = None
         cur_section = None
         for c in self._get_configs(directory, scope):

=== modified file 'bzrlib/globbing.py'
--- bzrlib/globbing.py	2010-07-21 10:17:11 +0000
+++ bzrlib/globbing.py	2011-06-13 22:39:49 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,10 @@
 
 import re
 
-from bzrlib import errors
+from bzrlib import (
+    errors,
+    lazy_regex,
+    )
 from bzrlib.trace import (
     mutter,
     warning,
@@ -217,9 +220,13 @@
 
     def _add_patterns(self, patterns, translator, prefix=''):
         while patterns:
-            grouped_rules = ['(%s)' % translator(pat) for pat in patterns[:99]]
+            grouped_rules = [
+                '(%s)' % translator(pat) for pat in patterns[:99]]
             joined_rule = '%s(?:%s)$' % (prefix, '|'.join(grouped_rules))
-            self._regex_patterns.append((re.compile(joined_rule, re.UNICODE),
+            # Explicitly use lazy_compile here, because we count on its
+            # nicer error reporting.
+            self._regex_patterns.append((
+                lazy_regex.lazy_compile(joined_rule, re.UNICODE),
                 patterns[:99]))
             patterns = patterns[99:]
 

=== modified file 'bzrlib/lazy_regex.py'
--- bzrlib/lazy_regex.py	2011-05-18 16:42:48 +0000
+++ bzrlib/lazy_regex.py	2011-06-13 22:39:49 +0000
@@ -16,8 +16,12 @@
 
 """Lazily compiled regex objects.
 
-This module defines a class which creates proxy objects for regex compilation.
-This allows overriding re.compile() to return lazily compiled objects.
+This module defines a class which creates proxy objects for regex
+compilation.  This allows overriding re.compile() to return lazily compiled
+objects.  
+
+We do this rather than just providing a new interface so that it will also
+be used by existing Python modules that create regexs.
 """
 
 import re

=== modified file 'bzrlib/tests/test_lazy_regex.py'
--- bzrlib/tests/test_lazy_regex.py	2011-06-13 22:11:11 +0000
+++ bzrlib/tests/test_lazy_regex.py	2011-06-13 22:39:49 +0000
@@ -124,17 +124,11 @@
     assume it is installed, and leave it installed when they're done.
     """
 
-    def setUp(self):
-        super(TestInstallLazyCompile, self).setUp()
-
     def test_install(self):
-        lazy_regex.reset_compile()
-        lazy_regex.install_lazy_compile()
         pattern = re.compile('foo')
         self.assertIsInstance(pattern, lazy_regex.LazyRegex)
 
     def test_reset(self):
-        lazy_regex.install_lazy_compile()
         lazy_regex.reset_compile()
         self.addCleanup(lazy_regex.install_lazy_compile)
         pattern = re.compile('foo')

